import sys

from forum.wtforms import TopicForm 
sys.path.append(".")
from forum.handler.BaseHandler import BaseHandler
from forum.models import TopicModel, UserModel
from forum.decorators import login_required_async
from uuid import uuid4
import os
from config import settings
 
#定义获取文章的函数
class GetManyTopicHandler(BaseHandler):
    async def get(self):
        topics = await self.obj.execute(TopicModel.select().order_by(TopicModel.create_time.desc()))
        # topics = await self.obj.execute(TopicModel.create_time.desc())
        #获取数据
        data = []
        for t in topics:
            d = t.to_json()
            d['content'] = d.get('content').decode()
            if t.imgs == None or t.imgs =='':
                d['imgs'] = None
            else:
                d['imgs'] = d.get('imgs').split(',')
            d['user'] = d.get('user').to_json()
            d['comment_num'] = t.comments.count()#显示评论数
            d['like_num'] = t.collections.count()
            data.append(d)
        return self.finish({'msg':'获取成功','code':200,'topics':data})
    #定义分类查询的方法
    async def post(self):
        type_ = self.get_body_argument('type')
        data = []
        topics = await self.obj.execute(TopicModel.select().where(TopicModel.type_ ==type_).order_by(TopicModel.create_time.desc()))
        for t in topics:
            d = trans_topic(t)
            data.append(d)
        return self.finish({'msg':'获取成功','code':200,'topics':data})


 #定义获取单个文章的函数
class GetOneTopicHandler(BaseHandler):
    async def post(self):
        id = self.get_body_argument('id')
        t = await self.obj.get(TopicModel,id = id)
        d = trans_topic(t)
        return self.finish({'msg':'获取成功','code':200,'topic':d})

#优化代码操作，不用写多次
def trans_topic(t):
    d = t.to_json()
    d['content'] = d.get('content').decode()
    if t.imgs == None or t.imgs =='':
        d['imgs'] = None
    else:
        d['imgs'] = d.get('imgs').split(',')
    d['user'] = d.get('user').to_json()
    return d

#定义发布帖子的功能
class AddTopicHandler(BaseHandler):
    @login_required_async
    async def post(self):
        user = await self.obj.get(UserModel,id = self._user_id)
        topic_form = TopicForm(**self.request.arguments)
        if topic_form.validate():
            imgs = self.request.files.get('imgs',[{}])#传递接收图片,[{}]空字典
            #发布帖子是发布图片的代码，跟头像的代码一样，去掉[0]，decode()转码
            pics = []
            for img in imgs:
                file_name = f'{uuid4().hex}{os.path.splitext(img.filename)[-1]}'
                full_name = os.path.join(settings.get('static_path'),'img',file_name)
                with open(full_name,'wb') as f:
                    f.write(img.body)
                pics.append(os.path.join('/static/img',file_name))
            await self.obj.create(TopicModel,
            id = uuid4(),
            title = topic_form.content.data[0].decode(),
            content = topic_form.content.data[0].decode(),
            type_ = topic_form.type_.data[0].decode(),
            imgs = ','.join(pics),
            user = user)
            # if rs > 0:
            return self.finish({'msg':'发贴成功','code':200})
        return self.finish({'msg':'发贴失败','code':500})


#发帖记录
# class GetMyTopicHandler(BaseHandler):
#     @login_required_async
#     async def post(self):
#         topics = await self.obj.execute(TopicModel.select().join(UserModel).where(UserModel.id == self._user_id).order_by(TopicModel.create_time.desc()))
#         data = []
#         for t in topics:
#             d = trans_topic(t)
#             data.append(d)
#         return self.finish({'msg':'获取个人帖子成功','code':200,'topics':data})


class GetMyTopicHandler(BaseHandler):
    @login_required_async
    async def post(self):
        topics =await self.obj.execute(TopicModel.select().join(UserModel).where(UserModel.id == self._user_id ).order_by(TopicModel.create_time.desc()))
        data =  []
        for t in topics:
            d = trans_topic(t)
            data.append(d)
        return self.finish({'msg':'获取个人帖子成功','code':200,'topics':data})