from peewee import *
from datetime import datetime

from peewee import BaseModelCursorWrapper
from forum import db

class BaseModel(Model):
    create_time = DateTimeField(default = datetime.now,verbose_name ='创建时间') 
    
    def to_json(self):
        r = {}
        for k in self.__data__.keys():
            if k == 'create_time':
                r[k] = str(getattr(self,k))#转成字符串
            else:
                r[k] = getattr(self,k)#否则原样放回去
        return r
     
    class Meta:
        database = db

#创建用户表
class UserModel(BaseModel):
    id = CharField(primary_key = True)
    email = CharField(max_length=32,verbose_name = '账号')
    nick_name = CharField(max_length=32,verbose_name = '昵称',null = True)
    password = CharField(max_length=32,verbose_name = '密码')
    gender = IntegerField(verbose_name = '性别',null = True)
    singatrue = CharField(max_length=128,verbose_name = '签名',null = True)
    pic = CharField(max_length=512,verbose_name = '头像',null = True)
    status = IntegerField(verbose_name = '账号状态',default = 1)

    class Meta:
        table_name = 't_user'

#创建文章数据库
class TopicModel(BaseModel):
    id = CharField(primary_key = True)
    title = CharField(verbose_name = '标题')
    imgs = CharField(verbose_name = '图片',max_length= 1000,null = True)
    content = BlobField(verbose_name='内容')
    chick_num = IntegerField(verbose_name='点击数',default= 0)
    type_ = CharField(verbose_name = '分类')
    user = ForeignKeyField(UserModel,backref='topics')

    class Meta:
        table_name = 't_topic'

#创建评论表
class CommentModel(BaseModel):
   id = CharField(primary_key = True)
   content = CharField(verbose_name = '内容')
   topic = ForeignKeyField(TopicModel,backref='comments')
   user = ForeignKeyField(UserModel,backref='comments')

   class Meta:
       table_name = 't_comment'

#创建收藏表
class CollectionModel(BaseModel):
    topic = ForeignKeyField(TopicModel,backref='collections')
    user = ForeignKeyField(UserModel,backref='collections')

    class Meta:
        table_name = 't_collection'
        primary_key = CompositeKey('topic','user')

'''
我关注的

关注我的
'''

#关注表
class FollowModel(BaseModel):
    to_user = ForeignKeyField(UserModel,backref='to_user')
    from_user = ForeignKeyField(UserModel,backref='from_user')

    class Meta:
        table_name = 't_follow'
        primary_key = CompositeKey('to_user','from_user')
   